@@ -1,5 +1,5 @@
 CA3variants<-
-function(Xdata, dims=c(p,q,r), ca3type = "CA3", test = 10^-6, resp="row", norder=3){ 
+function(Xdata, dims=c(p,q,r), ca3type = "CA3", test = 10^-6, resp="row", norder=3, sign=TRUE){ 
 #------------------------------------------
 #Xdata can be an array or raw data
 #--------------------------------------
@@ -30,13 +30,12 @@ if (is.array(Xdata)==FALSE) {stop("number of variables for three-way analysis mu
 #for (i in 1:dim(Xdata)[2]) colnames(Xdata)[i] <- paste("c",i,sep="")
 #}
 X <- as.array(Xdata)
-
 if (resp=="row"){
 p<-dims[[1]]
 q<-dims[[2]]
 r<-dims[[3]]
 }
-  #-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------------
 if ((resp=="col")||(resp=="column")){
 X<-aperm(X,c(2,1,3))
 p<-dims[[2]]
@@ -63,9 +62,10 @@ labelgij <- NULL
 pii <- apply(X/sum(X), 1, sum)
     pj <- apply(X/sum(X), 2, sum)
     pk <- apply(X/sum(X), 3, sum)
-    S <- switch(ca3type, "CA3" = ca3basic(X, p=p, q=q, r=r),  "NSCA3" = 
-                    nsca3basic(X, p=p, q=q, r=r),"OCA3" = oca3basic(X, p=p, q=q, r=r,norder=norder),
-                "ONSCA3" = onsca3basic(X, p=p, q=q, r=r,norder=norder))
+  #---------------------------
+    S <- switch(ca3type, "CA3" = ca3basic(X, p=p, q=q, r=r, sign=sign),  "NSCA3" = 
+                    nsca3basic(X, p=p, q=q, r=r, sign=sign),"OCA3" = oca3basic(X, p=p, q=q, r=r,norder=norder, sign=sign),
+                "ONSCA3" = onsca3basic(X, p=p, q=q, r=r,norder=norder, sign=sign))
      ######################################################################################
     #                                                                                                                                                                                                          #
     # Defines the analysis to be performed  for nominal variables- CA3 or NSCA3 -for ordinal variables OCA3 -ONSCA3    #
@@ -117,24 +117,40 @@ pjk<-index3res$pjk
     # Calculation of coordinates  for CA3  NSCA3   and all oordered variants                 #
     #                                                                  #
     ####################################################################
+#----sign core issue---
+#g<-sqrt(S$g^2) #the sign of core values will be always positive...
 
+g<-S$g
 #----------------------------------------------------------------------for biptype row and column-tube
    fiStandard <-  S$a
         # Standard row coordinates 
 ncore<-dim(S$g)
-fi <- S$a %*% flatten(S$g)
+ fidim<-ncore[1]
+fiCdim<-ncore[2]*ncore[3]   
+fi <- S$a %*% flatten(g)
+#------------------------------------core sign issue!!!
+#for (i in 1:fidim){
+#for (j in 1:fiCdim){
+#if (flatten(g)[i,j]<0) fiStandard[i,j]<-(-1)*fiStandard[i,j]
+#}}
+#------------------------------------------------------------
     # Principal row coordinates
 gjkStandard <- Kron(S$b,S$cc ) 
-    gjk <- Kron(S$b,S$cc) %*% t(flatten(S$g)) 
+    gjk <- Kron(S$b,S$cc) %*% t(flatten(g)) 
         # Calculating the column-tube principal coordinates
+#------------------------------------core sign issue!!!
+#for (i in 1:fidim){
+#for (j in 1:fiCdim){
+#if (flatten(g)[i,j]<0) 
+#gjkStandard[i,j]<-(-1)*gjkStandard[i,j]  #change the sign
+# fi[i,j]<-(-1)*fi[i,j]  #change the sign
+#}}
+#------------------------------------------------------------
 labelfi<-nomi
  for (i in 1:nk){
         labelgjk <- c(labelgjk, paste(nomj, nomk[i], sep = ""))
     }
- fidim<-ncore[1]
-#fiCdim<-q*r
-fiCdim<-ncore[2]*ncore[3]      
-    nr <- dim(gjk)[[1]]
+     nr <- dim(gjk)[[1]]
     nc <- dim(gjk)[[2]]
   nc2 <- dim(gjkStandard)[[2]]
 productfigjk <- fiStandard %*% t(gjk)
@@ -144,24 +160,11 @@ productfigjk <- fiStandard %*% t(gjk)
     dimnames(productfigjk) <- list(labelfi, labelgjk)
     dimnames(fi) <- list(labelfi, paste("ax", 1:fiCdim, sep = ""))
  dimnames(fiStandard) <- list(labelfi, paste("ax", 1:dim(S$a)[[2]], sep = ""))
-    ####################################################################
-    #                                                                  #
-    # Calculation scaleplot=gamma values                                       #
-    #                                                                  #
-    ####################################################################
-V1<-sum(diag(t(fiStandard)%*%fiStandard)) #for column-tube biplot
-V2<-sum(diag(t(gjk)%*%gjk))
-gammajk<-1/((nj*nk/ni)*V1/V2)^{1/4}
-#------------------------------------------------------
-VV1<-sum(diag(t(gjkStandard)%*%gjkStandard)) #for row biplot
-VV2<-sum(diag(t(fi)%*%fi))
-gammai<-1/((ni/nj*nk)*VV1/VV2)^{1/4}
-#--------------------------------------
 #---------------------------------------------------------------------------------------biptype =col and row-tube
 fjStandard <-  S$b # Standard col coordinates 
-fj <- S$b %*% flatten(aperm(S$g,c(2,1,3)))    # Principal col coordinates JxPR
+fj <- S$b %*% flatten(aperm(g,c(2,1,3)))    # Principal col coordinates JxPR
 gikStandard <- Kron(S$a,S$cc ) # interactive coordinates IKxPR
-    gik <- Kron(S$a,S$cc) %*% t(flatten(aperm(S$g,c(2,1,3)))) # interactive principal coordinates
+    gik <- Kron(S$a,S$cc) %*% t(flatten(aperm(g,c(2,1,3)))) # interactive principal coordinates
         # Calculating the labels for the column-tube principal coordinates
 labelfj<-nomj
  for (i in 1:nk){
@@ -180,19 +183,12 @@ productfjgik <- fjStandard %*% t(gik)
     dimnames(productfjgik) <- list(labelfj, labelgik)
     dimnames(fj) <- list(labelfj, paste("ax", 1:fjCdim, sep = ""))
  dimnames(fjStandard) <- list(labelfj, paste("ax", 1:dim(fjStandard)[[2]], sep = ""))
-V1<-sum(diag(t(fjStandard)%*%fjStandard)) #for row-tube biplot
-V2<-sum(diag(t(gik)%*%gik))
-gammaik<-1/((ni*nk/nj)*V1/V2)^{1/4}
-#------------------------------------------------------
-VV1<-sum(diag(t(gikStandard)%*%gikStandard)) #for col biplot
-VV2<-sum(diag(t(fj)%*%fj))
-gammaj<-1/((ni/nj*nk)*VV1/VV2)^{1/4}
 #--------------------------------------
 #---------------------------------------------------------------------------------------biptype tube and row-col
 fkStandard <-  S$cc # Standard col coordinates 
-fk <- S$cc %*% flatten(aperm(S$g,c(3,1,2)))    # Principal col coordinates JxPR
+fk <- S$cc %*% flatten(aperm(g,c(3,1,2)))    # Principal col coordinates JxPR
 gijStandard <- Kron(S$a,S$b ) # interactive coordinates IKxPR
-    gij <- Kron(S$a,S$b) %*% t(flatten(aperm(S$g,c(3,1,2)))) # interactive principal coordinates
+    gij <- Kron(S$a,S$b) %*% t(flatten(aperm(g,c(3,1,2)))) # interactive principal coordinates
 
         # Calculating the labels for the column-tube principal coordinates
 labelfk<-nomk
@@ -213,13 +209,6 @@ productfkgij <- fkStandard %*% t(gij)
     dimnames(productfkgij) <- list(labelfk, labelgij)
     dimnames(fk) <- list(labelfk, paste("ax", 1:fkCdim, sep = ""))
  dimnames(fkStandard) <- list(labelfk, paste("ax", 1:dim(fkStandard)[[2]], sep = ""))
-V1<-sum(diag(t(fkStandard)%*%fkStandard)) #for row-tube biplot
-V2<-sum(diag(t(gij)%*%gij))
-gammaij<-1/((ni*nj/nk)*V1/V2)^{1/4}
-#------------------------------------------------------
-VV1<-sum(diag(t(gijStandard)%*%gijStandard)) #for col biplot
-VV2<-sum(diag(t(fk)%*%fk))
-gammak<-1/((nk/nj*ni)*VV1/VV2)^{1/4}
 #--------------------------------------
     ####################################################################
     #                                                                  #
@@ -230,7 +219,7 @@ gammak<-1/((nk/nj*ni)*VV1/VV2)^{1/4}
     inertiatot<-sum(S$g^2) #inertia reconstructed when p,q and r are different from I, J and K dimensions
     inertiapcsum <- (sum(S$g^2)/inertiaorig*100)  
     inertiapc <- (S$g^2/inertiaorig*100)
-    inertiaRSS <- (inertiaorig-inertiatot)
+ #   inertiaRSS <- (inertiaorig-inertiatot)
 #----------------------------------------------------------for row and col-tube biplot
     inertiacoltub <- apply(inertiapc,1,sum)  
     inertiarow <- c(apply(inertiapc,c(2,3),sum)) 
@@ -245,17 +234,26 @@ gammak<-1/((nk/nj*ni)*VV1/VV2)^{1/4}
     names(inertiatube)<-paste("ax", 1:fkCdim, sep = "")
 #-----------------------------------------------------------------------------------------------------------------------
 
-ca3corporateresults<-list(Data = X, ca3type = ca3type, rows = ni, cols = nj, tubes = nk, labelfi =labelfi, labelgjk = labelgjk,labelfj =labelfj, labelgik = labelgik, labelfk =labelfk, labelgij = labelgij, iteration = S$iteration, pi=pii, pj=pj, pk=pk, pij=pij, pik=pik, pjk=pjk,
+#ca3corporateresults<-list(Data = X, ca3type = ca3type, rows = ni, cols = nj, tubes = nk, labelfi =labelfi, labelgjk = labelgjk,labelfj =labelfj, labelgik = labelgik, labelfk =labelfk, labelgij = #labelgij, iteration = S$iteration, pi=pii, pj=pj, pk=pk, pij=pij, pik=pik, pjk=pjk,
+#prp = S$prp, a=S$a,b=S$b,cc=S$cc,
+#fi = fi, fiStandard= fiStandard, gjk = gjk,gjkStandard=gjkStandard, fj = fj, fjStandard= fjStandard, gik = gik,gikStandard=gikStandard, 
+#fk = fk, fkStandard= fkStandard, gij = gij,gijStandard=gijStandard, 
+#inertiaorig = inertiaorig,inertiatot=inertiatot, inertiaRSS=inertiaRSS, inertiapc=inertiapc,
+#inertiapcsum = inertiapcsum, inertiacoltub = inertiacoltub,inertiarow=inertiarow, inertiarowtub = inertiarowtub,inertiacol=inertiacol,
+#inertiarowcol = inertiarowcol,inertiatube=inertiatube, iproductijk = productfigjk,iproductjik = productfjgik,iproductkij = productfkgij, 
+#g = S$g, index3res = index3res, index3=index3, 
+#gammai=gammai,gammajk=gammajk,
+#gammaj=gammaj,gammaik=gammaik,gammak=gammak,gammaij=gammaij)
+ 
+ca3corporateresults<-list(Data = X, ca3type = ca3type, resp=resp, iteration = S$iteration, pi=pii, pj=pj, pk=pk, pij=pij, pik=pik, pjk=pjk,
 prp = S$prp, a=S$a,b=S$b,cc=S$cc,
 fi = fi, fiStandard= fiStandard, gjk = gjk,gjkStandard=gjkStandard, fj = fj, fjStandard= fjStandard, gik = gik,gikStandard=gikStandard, 
 fk = fk, fkStandard= fkStandard, gij = gij,gijStandard=gijStandard, 
-inertiaorig = inertiaorig,inertiatot=inertiatot, inertiaRSS=inertiaRSS, inertiapc=inertiapc,
-inertiapcsum = inertiapcsum, inertiacoltub = inertiacoltub,inertiarow=inertiarow, inertiarowtub = inertiarowtub,inertiacol=inertiacol,
+inertiaorig = inertiaorig,inertiatot=inertiatot,  inertiapc=inertiapc, inertiacoltub = inertiacoltub,inertiarow=inertiarow, inertiarowtub = inertiarowtub,inertiacol=inertiacol,
 inertiarowcol = inertiarowcol,inertiatube=inertiatube, iproductijk = productfigjk,iproductjik = productfjgik,iproductkij = productfkgij, 
-g = S$g, index3res = index3res, index3=index3, 
-gammai=gammai,gammajk=gammajk,
-gammaj=gammaj,gammaik=gammaik,gammak=gammak,gammaij=gammaij)
- 
+g = S$g, index3res = index3res, index3=index3)
+
 class(ca3corporateresults)<-"CA3variants"
 invisible(return(ca3corporateresults))
 }
+
