@@ -1,4 +1,4 @@
-oca3basic<-function(x, p,q,r, test = 10^-6, ctr = T, std = T,norder=3)
+oca3basic<-function(x, p,q,r, test = 10^-6, ctr = T, std = T,norder=3,sign = TRUE)
 {
 #-------------------------------------------------------------------------
 #  3-way non-symmetrical correspondence analysis
@@ -10,7 +10,10 @@ oca3basic<-function(x, p,q,r, test = 10^-6, ctr = T, std = T,norder=3)
 #  ctr     (T or F) if F the analysis is not centered
 #---------------------------------------------------------------------------
 nnom <- dimnames(x)
-nomi <- nnom[[1]]
+I<-dim(x)[1]
+    J<-dim(x)[2]    
+    K<-dim(x)[3]
+   nomi <- nnom[[1]]
 nomj <- nnom[[2]]
 nomk <- nnom[[3]]
 tot<-sum(x)
@@ -18,15 +21,13 @@ n<-dim(x)
 pi <- apply(x/tot, 1, sum)
 devt <- 1 - sum(pi^2)
 xs <- standtab(x, ctr = ctr, std = std)*sqrt(tot)#la fun orig standtab
-#xs <- standtabnew(x, ctr = ctr, std = std)*sqrt(tot)#la fun orig standtab
-#browser()
-#xsg<-xs$xg
-#browser()
-#res <- tuckerORDEREDnotrivial(xsg, p=p, q=q, r=r,x, test=test,order=order)
+if (sign==TRUE){
 res <- tuckerORDERED(xs, p=p, q=q, r=r, x, test=test,norder=norder) #good
-#res <- tuckerORDERED(xsg, p=p, q=q, r=r, x=xsg, test=test,order=order) #but need to modify init3ordered to update poly
-#res<-signscore(res$a,res$b,res$cc,ni,nj,nk,p=ni-1,q=nj-1,r=nk-1,core=res$g,IFIXA=0,IFIXB=0,IFIXC=0) #given negative core, change signs in components
-#browser()
+res<-signscore(res$a,res$b,res$cc,I,J,K,p=p,q=q,r=r,core=res$g,IFIXA=0,IFIXB=0,IFIXC=0) #given negative core, change signs in components
+}
+if (sign==FALSE){
+res <- tuckerORDERED(xs, p=p, q=q, r=r, x, test=test,norder=norder) #good
+}
 ncore<-dim(res$g)
 np <- paste("p", 1:ncore[1], sep = "")
 nq <- paste("q", 1:ncore[2], sep = "")
